@@ -5,10 +5,11 @@ import json
 import os.path
 import glob
 import webbrowser
+import argparse
 import time
 
 
-__version__ = '2021.1.1.1'
+__version__ = '2022.10.1.2'
 
 
 class FailedToGetFileException(Exception):
@@ -69,14 +70,12 @@ def startauth(
     )
 
     # Start authentication process.
-    response = sso_oidc.start_device_authorization(
+    return sso_oidc.start_device_authorization(
         clientId=client_id,
         clientSecret=client_secret,
         startUrl=start_url
     )
 
-    return response
-
 
 def getclienttoken(
     client_id: str,
@@ -100,15 +99,13 @@ def getclienttoken(
     )
 
     # Get tokens.
-    response = sso_oidc.create_token(
+    return sso_oidc.create_token(
         clientId=client_id,
         clientSecret=client_secret,
         grantType=grant_type,
         deviceCode=device_code
     )
 
-    return response
-
 
 def getjsontoken(
     json_cache: str = None
@@ -133,7 +130,7 @@ def getjsontoken(
         if json_cache.startswith('~'):
             json_cache = json_cache.replace('~', home)
     except Exception as e:
-        list_of_files = glob.glob('{}/.aws/sso/cache/*.json'.format(home))
+        list_of_files = glob.glob(f'{home}/.aws/sso/cache/*.json')
         json_cache = max(list_of_files, key=os.path.getctime)
 
     # Raise exception if specified JSON cache file
@@ -187,8 +184,7 @@ def gettoken(
     )
 
     print(
-        'Verification URI: {}'.
-        format(response_start['verificationUriComplete'])
+        f'Verification URI: {response_start["verificationUriComplete"]}'
     )
 
     # Open web browser for authentication.
@@ -217,7 +213,6 @@ def gettoken(
             get_counter += 1
             if get_counter > timeout:
                 break
-            pass
 
     try:
         response
@@ -227,7 +222,64 @@ def gettoken(
         print('Request failed.')
         return {
             'message': (
-                'Failed to get Access Token after {} tries.'
-                .format(timeout)
+                f'Failed to get Access Token after {timeout} tries.'
             )
         }
+
+
+def get_params():
+    """Get parameters from script inputs."""
+    myparser = argparse.ArgumentParser(
+        add_help=True,
+        allow_abbrev=False,
+        description="Execute AWS SSO auth tasks.",
+        usage="%(prog)s [options]",
+    )
+    myparser.add_argument(
+        "-v", "--version", action="version", version="%(prog)s 2022.10.1.2"
+    )
+    myparser.add_argument(
+        "-u",
+        "--sso_url",
+        action="store",
+        help="AWS SSO login URL.",
+        required=True,
+        type=str,
+    )
+    myparser.add_argument(
+        "-c",
+        "--client_name",
+        action="store",
+        help="AWS SSO client name.",
+        nargs="?",
+        default="ssoclielnt",
+        required=False,
+        type=str,
+    )
+    myparser.add_argument(
+        "-r",
+        "--region",
+        action="store",
+        help="AWS SSO region.",
+        nargs="?",
+        default="us-east-1",
+        required=False,
+        type=str,
+    )
+    myparser.add_argument(
+        "-t",
+        "--timeout",
+        action="store",
+        help="Login attempt timeout duration in seconds.",
+        nargs="?",
+        default=30,
+        required=False,
+        type=str,
+    )
+    return myparser.parse_args()
+
+
+def main():
+    """Execute module as a script for testing purposes."""
+    response = gettoken(get_params().sso_url)
+    print({"access_token": response['accessToken']})
